INCLUDE_PARENTS = False
RECURSIVE_QUERIES = True
CLEVER_PARSING = True
QUERY_EXCEPTIONS = True
NATIVE_TYPES = False  # if True, the result of get method, or first, last, etc will be a python object instead of a jsonnode
